@@ -1,4 +1,5 @@
 import ast
+import asyncio
 import json
 import logging
 import subprocess
@@ -372,7 +373,9 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                 if isinstance(message, str) and message.startswith('{"command'):
                     subprocess_cmd(json.loads(message)["command"])
 
-            await pc.setLocalDescription(await pc.createOffer())
+            loop = asyncio.get_event_loop()
+            loop.run_until_complete(pc.setLocalDescription(await pc.createOffer()))
+
 
             self.sio.emit("watcher", {"target": description,
                                             "id": id,
@@ -389,13 +392,16 @@ class GSPeerConnectionBroadcasterPiSocketv2:
                         description = ast.literal_eval(description)
                     desc = type('new_dict', (object,), description)
                     answer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
-                    await self.peerConnections[id].setRemoteDescription(answer)
+                    loop = asyncio.get_event_loop()
+                    loop.run_until_complete( self.peerConnections[id].setRemoteDescription(answer))
+
 
         @self.sio.event
         def disconnectBroadcaster(id, desc):
             if id in self.peerConnections:
                 self._logger.info("Disconnected Peer")
-                await self.peerConnections[id].close()
+                loop = asyncio.get_event_loop()
+                loop.run_until_complete(self.peerConnections[id].close())
                 self.peerConnections.pop(id, None)
 
         @self.sio.event
